@@ -5,16 +5,22 @@ use tide::{Request, StatusCode};
 extern crate clap;
 use clap::App;
 
+pub mod channel;
 pub mod csp;
-pub mod mail;
+
+#[cfg(feature = "mail")]
+use channel::mailer::Mailer;
+
+#[cfg(feature = "sentry")]
+use channel::sentry::Sentry;
 
 extern crate dotenv;
 use dotenv::dotenv;
-use std::env;
 
 use crate::csp::csp_report::CspReport;
-use crate::mail::mailer::Mailer;
-use crate::mail::mailer_configuration::MailerConfiguration;
+
+#[cfg(any(feature = "mail", feature = "sentry"))]
+use crate::channel::channel::Channel;
 
 #[async_std::main]
 async fn main() -> tide::Result<()> {
@@ -50,33 +56,18 @@ async fn csp_report_action(mut req: Request<()>) -> tide::Result {
     let CspReport { csp_report } = req.body_json().await?;
 
     if !csp_report.is_in_block_list() {
-        let from_name = env::var("MORBO_FROM_NAME").unwrap();
-        let from_email = env::var("MORBO_FROM_EMAIL").unwrap();
-        let to_name = env::var("MORBO_TO_NAME").unwrap();
-        let to_email = env::var("MORBO_TO_EMAIL").unwrap();
-
-        let smtp_hostname = env::var("MORBO_SMTP_HOSTNAME").unwrap();
-        let smtp_port = env::var("MORBO_SMTP_PORT").unwrap().parse().unwrap();
-        let smtp_username = env::var("MORBO_SMTP_USERNAME").unwrap();
-        let smtp_password = env::var("MORBO_SMTP_PASSWORD").unwrap();
-
-        let mailer_configuration = MailerConfiguration {
-            from_name,
-            from_email,
-            to_name,
-            to_email,
-            smtp_hostname,
-            smtp_port,
-            smtp_username: Some(smtp_username),
-            smtp_password: Some(smtp_password),
+        #[cfg(feature = "mail")]
+        let _ = || {
+            let mailer = Mailer::load_from_env();
+            let _res = mailer.send_report(&csp_report).unwrap();
         };
 
-        let mailer = Mailer {
-            configuration: mailer_configuration,
+        #[cfg(feature = "sentry")]
+        let _ = || {
+            let sentry = Sentry::load_from_env();
+            let _res = sentry.send_report(&csp_report).unwrap();
         };
 
-        let _res = mailer.send_report(&csp_report)?;
-
         Ok(format!(
             "CSP report: {}",
             serde_json::to_string_pretty(&csp_report).unwrap()
